@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Facebook, Inc. and its affiliates.
+ * Copyright (c) Meta Platforms, Inc. and affiliates.
  *
  * This source code is licensed under both the MIT license found in the
  * LICENSE-MIT file in the root directory of this source tree and the Apache
@@ -203,40 +203,40 @@ impl<A: Ord + ?Sized> Ord for ARef<'_, A> {
 /// Obtain an [`ARef`] from either a normal pointer or a [`RefCell`](std::cell::RefCell).
 pub trait AsARef<T: ?Sized> {
     /// Get an [`ARef`] pointing at this type.
-    fn as_aref(&self) -> ARef<T>;
+    fn as_aref(this: &Self) -> ARef<T>;
     /// Try and get an [`ARef`] pointing at this type. Returns an [`Err`] if
     /// the type `Self` is a [`RefCell`] which is already mutably borrowed.
-    fn try_as_aref(&self) -> Result<ARef<T>, BorrowError>;
+    fn try_as_aref(this: &Self) -> Result<ARef<T>, BorrowError>;
     /// Return the underlying [`RefCell`] if `Self` is one, otherwise [`None`].
-    fn as_ref_cell(&self) -> Option<&RefCell<T>>;
+    fn as_ref_cell(this: &Self) -> Option<&RefCell<T>>;
 }
 
 impl<T: ?Sized> AsARef<T> for T {
-    fn as_aref(&self) -> ARef<T> {
-        ARef::new_ptr(self)
+    fn as_aref(this: &Self) -> ARef<T> {
+        ARef::new_ptr(this)
     }
-    fn try_as_aref(&self) -> Result<ARef<T>, BorrowError> {
-        Ok(ARef::new_ptr(self))
+    fn try_as_aref(this: &Self) -> Result<ARef<T>, BorrowError> {
+        Ok(ARef::new_ptr(this))
     }
-    fn as_ref_cell(&self) -> Option<&RefCell<T>> {
+    fn as_ref_cell(_this: &Self) -> Option<&RefCell<T>> {
         None
     }
 }
 
 impl<T: ?Sized> AsARef<T> for RefCell<T> {
-    fn as_aref(&self) -> ARef<T> {
-        ARef::new_ref(self.borrow())
+    fn as_aref(this: &Self) -> ARef<T> {
+        ARef::new_ref(this.borrow())
     }
-    fn try_as_aref(&self) -> Result<ARef<T>, BorrowError> {
-        Ok(ARef::new_ref(self.try_borrow()?))
+    fn try_as_aref(this: &Self) -> Result<ARef<T>, BorrowError> {
+        Ok(ARef::new_ref(this.try_borrow()?))
     }
-    fn as_ref_cell(&self) -> Option<&RefCell<T>> {
-        Some(self)
+    fn as_ref_cell(this: &Self) -> Option<&RefCell<T>> {
+        Some(this)
     }
 }
 
 #[cfg(test)]
-mod test {
+mod tests {
     use std::{cell::RefCell, mem};
 
     use super::*;
@@ -317,7 +317,7 @@ mod test {
     #[test]
     fn test_as_aref() {
         fn get_str(x: &impl AsARef<String>) -> ARef<str> {
-            ARef::map(x.as_aref(), |x| x.as_str())
+            ARef::map(AsARef::as_aref(x), |x| x.as_str())
         }
 
         let a = RefCell::new("hello".to_owned());
