@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Facebook, Inc. and its affiliates.
+ * Copyright (c) Meta Platforms, Inc. and affiliates.
  *
  * This source code is licensed under both the MIT license found in the
  * LICENSE-MIT file in the root directory of this source tree and the Apache
@@ -147,7 +147,9 @@ where
 }
 
 #[cfg(test)]
-mod test {
+mod tests {
+    use std::marker;
+
     use super::*;
     use crate as gazebo;
 
@@ -170,4 +172,32 @@ mod test {
         let newtype = NewtypeWithLifetime(&[1, 2]);
         assert_eq!(&[1, 2], coerce(newtype))
     }
+
+    #[test]
+    fn test_coerce_type_and_lifetime_params() {
+        #[derive(Coerce)]
+        #[repr(C)]
+        struct Aaa<'a>(&'a u32);
+        #[derive(Coerce)]
+        #[repr(C)]
+        struct Bbb<'a>(&'a u32);
+
+        unsafe impl<'a> Coerce<Bbb<'a>> for Aaa<'a> {}
+
+        #[derive(Coerce)]
+        #[repr(C)]
+        struct StructWithLifetimeAndTypeParams<'a, X> {
+            x: X,
+            _marker: marker::PhantomData<&'a u32>,
+        }
+
+        let ten = 10;
+        let old = StructWithLifetimeAndTypeParams::<Aaa> {
+            x: Aaa(&ten),
+            _marker: marker::PhantomData,
+        };
+
+        let new: StructWithLifetimeAndTypeParams<Bbb> = coerce(old);
+        assert_eq!(10, *new.x.0);
+    }
 }
