@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Facebook, Inc. and its affiliates.
+ * Copyright (c) Meta Platforms, Inc. and affiliates.
  *
  * This source code is licensed under both the MIT license found in the
  * LICENSE-MIT file in the root directory of this source tree and the Apache
@@ -30,10 +30,8 @@ pub mod variants;
 mod test;
 
 /// Causes Rust to exit the process when any panic occurs.
-#[deprecated(
-    since = "0.4.2",
-    note = "Compiling with -Cpanic=abort provides similar behavior and smaller binaries"
-)]
+/// An alternative is to compile your binary _and all dependencies_
+/// with `-Cpanic=abort`, which will provide similar behavior and smaller libraries.
 pub fn terminate_on_panic() {
     let orig_hook = std::panic::take_hook();
     std::panic::set_hook(Box::new(move |panic_info| {
